@@ -8,13 +8,13 @@ enum book_type
     BOOK_CONJURATIONS,
     BOOK_FLAMES,
     BOOK_FROST,
-    BOOK_SUMMONINGS,
+    BOOK_DRYADS,
     BOOK_FIRE,
     BOOK_ICE,
     BOOK_SPATIAL_TRANSLOCATIONS,
     BOOK_HEXES,
     BOOK_YOUNG_POISONERS,
-    BOOK_TEMPESTS,
+    BOOK_LIGHTNING,
     BOOK_DEATH,
     BOOK_MISFORTUNE,
     BOOK_CHANGES,
@@ -23,7 +23,7 @@ enum book_type
 #if TAG_MAJOR_VERSION == 34
     BOOK_WAR_CHANTS = BOOK_FEN,
 #endif
-    BOOK_CLOUDS,
+    BOOK_VAPOURS,
     BOOK_NECROMANCY,
     BOOK_CALLINGS,
     BOOK_MALEDICT,
@@ -39,7 +39,7 @@ enum book_type
     BOOK_BATTLE, // was BOOK_MUTATIONS
 #endif
     BOOK_GEOMANCY,
-    BOOK_EARTH,
+    BOOK_STONE,
 #if TAG_MAJOR_VERSION == 34
     BOOK_WIZARDRY,
 #endif
@@ -54,9 +54,7 @@ enum book_type
     BOOK_BURGLARY,
     BOOK_DREAMS,
     BOOK_ALCHEMY,
-#if TAG_MAJOR_VERSION == 34
     BOOK_BEASTS,
-#endif
 
     BOOK_ANNIHILATIONS,
     BOOK_GRAND_GRIMOIRE,
@@ -71,8 +69,38 @@ enum book_type
 #if TAG_MAJOR_VERSION == 34
     BOOK_BUGGY_DESTRUCTION,
 #endif
+
+    BOOK_SPECTACLE,
+    BOOK_WINTER,
+    BOOK_SPHERES,
+    BOOK_ARMAMENTS,
+    BOOK_PAIN,
+    BOOK_DECAY,
+    BOOK_DISPLACEMENT,
+    BOOK_RIME,
+    BOOK_EVERBURNING,
+    BOOK_EARTH,
+    BOOK_OZOCUBU,
+    BOOK_SENSES,
+    BOOK_MOON,
+    BOOK_BLASTING,
+    BOOK_IRON,
+    BOOK_NEARBY,
+    BOOK_TUNDRA,
+    BOOK_STORMS,
+    BOOK_WEAPONS,
+    BOOK_SLOTH,
+    BOOK_BLOOD,
+    BOOK_THERE_AND_BACK,
+    BOOK_DANGEROUS_FRIENDS,
+    BOOK_TOUCH,
+    BOOK_CHAOS,
+    BOOK_UNRESTRAINED,
+    BOOK_BIOGRAPHIES_II,
+    BOOK_BIOGRAPHIES_VII,
+    BOOK_TRISMEGISTUS,
+    BOOK_HUNTER,
     NUM_BOOKS
 };
 
-#define NUM_NORMAL_BOOKS     (MAX_NORMAL_BOOK + 1)
 #define NUM_FIXED_BOOKS      (MAX_FIXED_BOOK + 1)
