@@ -299,7 +299,7 @@ void list_jewellery()
 {
     string jstr;
     int cols = get_number_of_cols() - 1;
-    bool split = you.species == SP_OCTOPODE && cols > 84;
+    bool split = species::arm_count(you.species) > 2 && cols > 84;
 
     for (int j = EQ_LEFT_RING; j < NUM_EQUIP; j++)
     {
@@ -346,11 +346,9 @@ void list_jewellery()
                            split && i > EQ_AMULET ? (cols - 1) / 2 : cols);
         item = colour_string(item, colour);
 
-        if (i == EQ_RING_SEVEN && you.species == SP_OCTOPODE &&
-                you.get_mutation_level(MUT_MISSING_HAND))
-        {
+        // doesn't handle arbitrary arm counts
+        if (i == EQ_RING_SEVEN && you.arm_count() == 7)
             mprf(MSGCH_EQUIPMENT, "%s", item.c_str());
-        }
         else if (split && i > EQ_AMULET && (i - EQ_AMULET) % 2)
             jstr = item + " ";
         else
@@ -766,8 +764,8 @@ static void _add_formatted_keyhelp(column_composer &cols)
     _add_insert_commands(cols, 0, item_types,
                          { CMD_MEMORISE_SPELL, CMD_CAST_SPELL,
                            CMD_FORCE_CAST_SPELL });
-    _add_insert_commands(cols, 0, "<brown>\\</brown> : staves (<w>%</w>ield and e<w>%</w>oke)",
-                         { CMD_WIELD_WEAPON, CMD_EVOKE_WIELDED });
+    _add_insert_commands(cols, 0, "<brown>|</brown> : staves (<w>%</w>ield)",
+                         { CMD_WIELD_WEAPON});
     _add_insert_commands(cols, 0, "<lightgreen>}</lightgreen> : miscellaneous items (e<w>%</w>oke)",
                          { CMD_EVOKE });
     _add_insert_commands(cols, 0, "<yellow>$</yellow> : gold (<w>%</w> counts gold)",
@@ -801,15 +799,17 @@ static void _add_formatted_keyhelp(column_composer &cols)
             0,
             "<h>Non-Gameplay Commands / Info\n");
 
+    _add_command(cols, 0, CMD_GAME_MENU, "game menu", 2);
     _add_command(cols, 0, CMD_REPLAY_MESSAGES, "show Previous messages");
     _add_command(cols, 0, CMD_REDRAW_SCREEN, "Redraw screen");
     _add_command(cols, 0, CMD_CLEAR_MAP, "Clear main and level maps");
+    _add_command(cols, 0, CMD_MACRO_ADD, "quick add macro");
+    _add_command(cols, 0, CMD_MACRO_MENU, "edit macros");
     _add_command(cols, 0, CMD_ANNOTATE_LEVEL, "annotate the dungeon level", 2);
     _add_command(cols, 0, CMD_CHARACTER_DUMP, "dump character to file", 2);
     _add_insert_commands(cols, 0, 2, CMD_MAKE_NOTE,
                          "add note (use <w>%:</w> to read notes)",
                          { CMD_DISPLAY_COMMANDS });
-    _add_command(cols, 0, CMD_MACRO_ADD, "add macro (also <w>Ctrl-D</w>)", 2);
     _add_command(cols, 0, CMD_ADJUST_INVENTORY, "reassign inventory/spell letters", 2);
 #ifdef USE_TILE_LOCAL
     _add_command(cols, 0, CMD_EDIT_PLAYER_TILE, "edit player doll", 2);
@@ -912,7 +912,7 @@ static void _add_formatted_keyhelp(column_composer &cols)
     _add_command(cols, 1, CMD_QUIVER_ITEM, "select action to be Quivered", 2);
     _add_command(cols, 1, CMD_SWAP_QUIVER_RECENT, "swap between most recent quiver actions", 2);
     _add_command(cols, 1, CMD_QUAFF, "Quaff a potion", 2);
-    _add_command(cols, 1, CMD_READ, "Read a scroll (or book on floor)", 2);
+    _add_command(cols, 1, CMD_READ, "Read a scroll", 2);
     _add_command(cols, 1, CMD_WIELD_WEAPON, "Wield an item (<w>-</w> for none)", 2);
     _add_command(cols, 1, CMD_WEAPON_SWAP, "wield item a, or switch to b", 2);
 
@@ -1069,9 +1069,9 @@ static void _add_formatted_hints_help(column_composer &cols)
     item_types += stringize_glyph(get_item_symbol(SHOW_ITEM_STAFF));
     item_types +=
         "</brown> : </console>"
-        "staves (<w>%</w>ield and e<w>%</w>oke)";
+        "staves (<w>%</w>ield)";
     _add_insert_commands(cols, 1, item_types,
-                         { CMD_WIELD_WEAPON, CMD_EVOKE_WIELDED });
+                         { CMD_WIELD_WEAPON });
 
     cols.add_formatted(1, " ", false);
     _add_command(cols, 1, CMD_DISPLAY_INVENTORY, "inventory (select item to view)", 2);
