@@ -159,7 +159,6 @@ static string shoptype_to_string(shop_type s)
     case SHOP_GENERAL:         return "<w>*</w>";
     case SHOP_GENERAL_ANTIQUE: return "<yellow>*</yellow>";
     case SHOP_JEWELLERY:       return "<w>=</w>";
-    case SHOP_EVOKABLES:       return "<w>}</w>";
     case SHOP_BOOK:            return "<w>:</w>";
     case SHOP_DISTILLERY:      return "<w>!</w>";
     case SHOP_SCROLL:          return "<w>?</w>";
@@ -387,7 +386,7 @@ static string _get_branches(bool display)
 static string _get_altars(bool display)
 {
     // Just wastes space for demigods.
-    if (you.species == SP_DEMIGOD)
+    if (you.has_mutation(MUT_FORLORN))
         return "";
 
     string disp;
@@ -794,9 +793,11 @@ static void _update_tracked_feature_annot(dungeon_feature_type feat,
     else if (new_num == 0)
     {
         level_annotations[li] = replace_all(level_annotations[li],
-                                            ", " + old_string, "");
+                                            old_string + ", ", "");
         level_annotations[li] = replace_all(level_annotations[li],
                                             old_string, "");
+        trim_string(level_annotations[li]);
+        strip_suffix(level_annotations[li], ",");
     }
 }
 
