@@ -60,6 +60,14 @@ const char * const GOZAG_SHOP_COST_KEY       = "gozag_shop_cost_%d";
 #define WU_JIAN_HEAVENLY_STORM_INITIAL 5
 #define WU_JIAN_HEAVENLY_STORM_MAX 15
 
+#define AVAILABLE_CURSE_KEY "available_curses"
+#define CURSE_KNOWLEDGE_KEY "current_curse_offer"
+
+#define ASHENZARI_CURSE_PROGRESS_KEY "ashenzari_progress_to_next_curse"
+#define ASHENZARI_CURSE_DELAY_KEY "ashenzari_curse_delay"
+#define ASHENZARI_BASE_PIETY 2
+#define ASHENZARI_PIETY_SCALE 168
+
 struct bolt;
 class stack_iterator;
 
@@ -108,7 +116,7 @@ void yred_make_enslaved_soul(monster* mon, bool force_hostile = false);
 
 bool kiku_receive_corpses(int pow);
 bool kiku_take_corpse();
-bool kiku_gift_necronomicon();
+bool kiku_gift_capstone_spells();
 
 bool fedhas_passthrough_class(const monster_type mc);
 bool fedhas_passthrough(const monster* target);
@@ -121,9 +129,14 @@ void cheibriados_time_bend(int pow);
 void cheibriados_temporal_distortion();
 bool cheibriados_slouch();
 void cheibriados_time_step(int pow);
-bool ashenzari_transfer_knowledge();
-bool ashenzari_end_transfer(bool finished = false, bool force = false);
-bool ashenzari_curse_item(int num_rc);
+
+void ashenzari_offer_new_curse();
+bool ashenzari_curse_item();
+bool ashenzari_uncurse_item();
+string desc_curse_skills(const CrawlStoreValue& curse);
+string curse_abbr(const CrawlStoreValue& curse);
+string curse_name(const CrawlStoreValue& curse);
+const vector<skill_type>& curse_skills(const CrawlStoreValue& curse);
 
 bool can_convert_to_beogh();
 void spare_beogh_convert();
@@ -164,9 +177,6 @@ int cell_has_valid_target(coord_def where);
 bool ru_apocalypse();
 string ru_sacrifice_vector(ability_type sac);
 
-int pakellas_effective_hex_power(int pow);
-int pakellas_surge_devices();
-
 bool uskayaw_stomp();
 bool uskayaw_line_pass();
 spret uskayaw_grand_finale(bool fail);
