@@ -75,6 +75,7 @@ int SpellRegion::handle_mouse(wm_mouse_event &event)
     {
         describe_spell(spell);
         redraw_screen();
+        update_screen();
         return CK_MOUSE_CMD;
     }
     return 0;
@@ -207,9 +208,7 @@ void SpellRegion::update()
         desc.idx      = (int) spell;
         desc.quantity = spell_mana(spell);
 
-        if ((spell == SPELL_BLINK || spell == SPELL_CONTROLLED_BLINK)
-             && you.no_tele(false, false, true)
-            || spell_is_useless(spell, true, true)
+        if (spell_is_useless(spell, true, true)
             || spell_mana(spell) > you.magic_points)
         {
             desc.flag |= TILEI_FLAG_INVALID;
